pub enum ComplexAttributeStrategy {
SeparateTable,
Flatten,
}Expand description
How to fold a complex attribute (composite or multivalued).
Variants
SeparateTable
Create a separate table joined by FK to the owning entity. Always safe and is the brModelo default for multivalued attributes.
Flatten
Flatten into the owner table by prefixing column names with the composite/multivalued attribute’s name. Only valid when the maximum cardinality is small and known.